
function [modifiedSection] = addSourceCodeToSection(section, files)
% ADDSOURCECODETOSECTION    Bundles sourceCode with a VHIST section.
%    Takes the given sourcecode and bundles it into a zip archive. This
%    archive is then included into the given section. A modified section is
%    returned, the original section is not modified.
%    
%    [NEWSEC] = ADDSOURCECODETOSECTION(OLDSEC, FILES)
%
%    Takes a number of filenames (which can contain the wildcard character
%    *), stored in the cell array FILES and zips these files into an
%    archive. The archive is embedded into the VhistSection OLDSEC. OLDSEC
%    is not modified, but instead a modified copy of OLDSEC is returned
%    (NEWSEC).

tmpDir = tempname();
mkdir(tmpDir);
tmpDeleter = matvhist.TempFile(tmpDir);

zipname = [tmpDir filesep 'sourcecode.zip'];
zip(zipname, files);

source = matvhist.VhistFile(zipname, 'in', 'The sourcecode of the project', ...
    'application/zip');


section.files = [section.files, source];
section.private__tempFiles = [section.private__tempFiles {tmpDeleter}];
modifiedSection = section;

end
