function [newSection, firstFile] = addVhistFilesForInputFiles(section, ...
                                   patterns, preferedFirstFiles)

if nargin < 3
    preferedFirstFiles = {};
end

newSection = section;
fileList = [];
foundAFile = false;
firstFile = '';

translate = @(x) regexptranslate('wildcard', x);
patterns = cellstr(patterns);
regexps = cellfun(translate, patterns, 'UniformOutput', false);

% search for an in-file, whos VHIST file does exist and is in
% preferedFirstFiles. Use this file as firstFile.
for i = 1 : numel(section.files)
    file = section.files(i);
    if strcmp(file.purpose, 'in')
        vhistName = [file.filename '.vhist'];
        if exist(vhistName, 'file')
            if any(strcmp(vhistName, preferedFirstFiles))
                firstFile = vhistName;
                foundAFile = true;
                break;
            end
        end
    end
end


for i = 1 : numel(section.files)
    file = section.files(i);
    fileList = [fileList, file];
    if strcmp(file.purpose, 'in')
        if isempty(regexps) || matvhist.matchesAnyRegexp(file.filename, ...
                                                         regexps)
            vhistName = [file.filename '.vhist'];
            if ~foundAFile && exist(vhistName, 'file')
                firstFile = vhistName;
                foundAFile = true;
            elseif ~strcmp(vhistName, firstFile)
                vhistFile = matvhist.VhistFile(vhistName, 'in');
                vhistFile.optional = true;
                fileList = [fileList vhistFile];
            end
        end
    end
end

newSection.files = fileList;

end
