
function [argfile] = buildArgfileText(section, prefix, postfix)
    sectionArray = buildSectionArray(section, prefix, postfix);
    argfile = arrayToString(sectionArray);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [sectionArray] = buildSectionArray(section, prefix, postfix)
    sectionArray =  prefix;

    % fill array with values from section
    if ischar(section.title)
        sectionArray = [sectionArray, '-s', 'title', section.title];
    end

    if ischar(section.description)
        sectionArray = [sectionArray, '-s', 'description', section.description];
    end

    if ischar(section.comment)
        sectionArray = [sectionArray, '-s', 'comment', section.comment];
    end

    if ischar(section.command)
        sectionArray = [sectionArray, '-s', 'command', section.command];
    end

    if ischar(section.host)
        sectionArray = [sectionArray, '-s', 'host', section.host];
    end

    if ischar(section.user)
        sectionArray = [sectionArray, '-s', 'user', section.user];
    end

    if ischar(section.tool)
        sectionArray = [sectionArray, '-s', 'tool', section.tool];
    end

    if ischar(section.toolpath)
        sectionArray = [sectionArray, '-s', 'toolpath', section.toolpath];
    end
    
    userKeys = section.userAttrs.keys;
    for i=1:numel(userKeys)
        key = userKeys{i};
        value = section.userAttrs(key);
        sectionArray = [sectionArray, '-U', key, value];
    end
    
    for i=1:numel(section.private__previewFiles)
        nextFile = section.private__previewFiles(i);
        fileArray = buildFileArray(nextFile);
        sectionArray = [sectionArray fileArray];
    end
    
    for i=1:numel(section.files)
        nextFile = section.files(i);
        fileArray = buildFileArray(nextFile);
        sectionArray = [sectionArray fileArray];
    end
    
    sectionArray = [sectionArray, postfix];
end

function [fileArray] = buildFileArray(file)
    fileArray = {};
    if strcmp(file.purpose, 'in')
        fileArray = [fileArray '-i'];
    else
        fileArray = [fileArray '-o'];
    end
    
    if ischar(file.filename)
        fileArray = [fileArray, file.filename];
    end
    
    if ischar(file.description)
        fileArray = [fileArray, '-a', 'description', file.description];
    end
    
    if ischar(file.filetype)
        fileArray = [fileArray, '-a', 'filetype', file.filetype];
    end
    
    if ischar(file.comment)
        fileArray = [fileArray, '-a', 'comment', file.comment];
    end
    
    if ischar(file.md5file)
        fileArray = [fileArray, '-a', 'md5file', file.md5file];
    end
    
    if islogical(file.embed)
        fileArray = [fileArray, '-f', bool2flag(file.embed, 'embed')];
    end
    
    if islogical(file.compress)
        fileArray = [fileArray, '-f', bool2flag(file.compress, 'compress')];
    end
    
    if islogical(file.optional)
        fileArray = [fileArray, '-f', bool2flag(file.optional, 'optional')];
    end
    
    if islogical(file.automd5)
        fileArray = [fileArray, '-f', bool2flag(file.automd5, 'automd5')];
    end
    
    if islogical(file.isPreview)
        fileArray = [fileArray, '-f', bool2flag(file.isPreview, 'preview')];
    end

    if islogical(file.isPreviewWs)
        fileArray = [fileArray, '-f', bool2flag(file.isPreviewWs, 'previewws')];
    end
    
    userKeys = file.userAttrs.keys;
    for i=1:numel(userKeys)
        key = userKeys{i};
        value = file.userAttrs(key);
        fileArray = [fileArray, '-u', key, value];
    end
    
    for i=1:numel(file.private__previewFiles)
        nextFile = file.private__previewFiles(i);
        subFileArray = buildFileArray(nextFile);
        fileArray = [fileArray subFileArray];
    end    
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [sectionString] = arrayToString(array)
    sectionString = '';
    for i=1:numel(array)
        nextString = escapeString(array{i});
        sectionString = [sectionString, nextString, ' '];
    end
end

function [escapedString] = escapeString(string)
    escapedString = strrep(strrep(string, '\', '\\'), '"', '\"');
    escapedString = ['"', escapedString, '"'];
end

function [result] = bool2flag(state, flagString)
    if state
        result = flagString;
    else
        result = ['no-' flagString];
    end
end
