
function [newSectionOrFile] = createPreviews(sectionOrFile, tmpDir)

newSectionOrFile = sectionOrFile;

if isa(newSectionOrFile, 'matvhist.VhistSection')
    title = newSectionOrFile.title;
    classtype = 'section';
    prefix = '';
elseif isa(newSectionOrFile, 'matvhist.VhistFile')
    [~, fname, fext] = fileparts(newSectionOrFile.filename);
    title = [fname fext];
    classtype = 'file';
    prefix = title;
else
    throw(MException('vhist:wrongType', 'sectionOrFile must be of type VhistSection or VhistFile'));
end

for i=1:numel(sectionOrFile.previews)
    curPreview = sectionOrFile.previews{i};
    % preview is a filename?
    if ischar(curPreview)
        newFile = createPreviewFromFile(title, classtype, curPreview);
        newSectionOrFile.private__previewFiles = [newSectionOrFile.private__previewFiles, newFile];
    % preview is a figure id?
    elseif numel(curPreview) == 1
        newFile = createPreviewFromFigure(title, prefix, classtype, tmpDir, curPreview);
        newSectionOrFile.private__previewFiles = [newSectionOrFile.private__previewFiles, newFile];
    % preview is a grayscale image or rgb image?
    elseif ndims(curPreview) == 2 || (ndims(curPreview) == 3 && size(curPreview, 3) == 3)
        newFile = createPreviewFromImage(title, prefix, classtype, tmpDir, curPreview);
        newSectionOrFile.private__previewFiles = [newSectionOrFile.private__previewFiles, newFile];
    else
        throw(MException('vhist:wrongType', 'preview must be a figure, an image or a filename to an image file'));
    end
end

end


function [newFile] = createPreviewFromImage(title, prefix, classtype, tmpDir, image)
   
filename = createUniquePreviewname(prefix, tmpDir);

imwrite(image, filename, 'png');
newFile = createPreviewFromFile(title, classtype, filename);

end


function [newFile] = createPreviewFromFigure(title, prefix, classtype, tmpDir, figureId)
   
filename = createUniquePreviewname(prefix, tmpDir);

ppos = get(figureId, 'PaperPosition');
unit = get(figureId, 'PaperUnit');

% convert to inches
if isequal(unit, 'centimeters')
    ppos = ppos / 2.54;
elseif isequal(unit, 'points')
    ppos = ppos / 72.;
end
% inches do not need conversion, don't know how to handle normalized

resolution = 500 / ppos(3);
print(figureId, filename, '-dpng', ['-r' num2str(resolution)]);
newFile = createPreviewFromFile(title, classtype, filename);

end


function [newFile] = createPreviewFromFile(title, classtype, filename)

desc = sprintf('preview image for %s ''%s''', classtype, char(title));
f = matvhist.VhistFile(filename, 'in', desc);
f.isPreviewWs = strcmp(classtype, 'section');
f.isPreview = strcmp(classtype, 'file');
f.isThumbnail = false;
f.isThumbnailOnly = false;
f.embed = true;
newFile = f;

end


function [uniqueName] = createUniquePreviewname(prefix, tmpDir)

if ~strcmp(prefix, '')
    prefix = ['_', prefix];
end

suggestion = [tmpDir, filesep, 'preview', prefix, '.', 'png'];
nextId = 1;
while exist(suggestion, 'file')
    suggestion = [tmpDir, filesep, 'preview_', int2str(nextId), prefix, '.', 'png'];
    nextId = nextId + 1;
end

uniqueName = suggestion;

end
