function [found, vhistexec] = findVhistExec()
% FINDVHISTEXEC    Returns the path to a vhistadd executable usable on this
%                  system.
%    This function searches for a vhistadd executable in the directory of
%    the matvhist bindings and returns the path to this executable.
%    On Windows, .exe Versions of vhistadd will be prefered.

if isunix()
    [found, vhistexec] = findOnUnix();
else % guess windows
end

end

function [found, vhistexec] = findOnUnix()

pathStr = getenv('PATH');
pathList = splitPath(pathStr, ':');
for i = 1 : numel(pathList)
    pathPart = pathList{i};
    [found, filename] = checkDir(pathPart);
    if found
        vhistexec = [pathPart filesep filename];
        return;
    end
end

found = false;
vhistexec = '';

end

function [pathList] = splitPath(pathStr, sepChar)

pathList = {};
seps = strfind(pathStr, sepChar);
pos1 = 1;

for i = 1 : numel(seps)
    pos2 = seps(i);
    nextPath = pathStr(pos1:(pos2-1));
    pos1 = seps(i) + 1;
    if ~strcmp(nextPath, '')
        pathList = [pathList, nextPath];
    end
end

if numel(pathStr) >= pos1;
    nextPath = pathStr(pos1:numel(pathStr));
    pathList = [pathList nextPath];
end

end


function [found, filename] = checkDir(dirname)

regStr = 'vhistadd(\.(py|exe))?';
regStrVersioned = 'vhistadd-[0-9]+(\.(py|exe))?';

foundMatches = {};
foundMatchesVersioned = {};

listing = dir(dirname);
for i = 1 : numel(listing)
    curFile = listing(i);
    if ~curFile.isdir && ~isempty(strfind(curFile.name, 'vhistadd'))
        
        [start, endPos] = regexp(curFile.name, regStrVersioned);
        if numel(start) == 1 && start == 1 && endPos == numel(curFile.name)
            foundMatchesVersioned = [foundMatchesVersioned curFile.name];
        else
            [start, endPos] = regexp(curFile.name, regStr);
            if numel(start) == 1 && start == 1 && endPos == numel(curFile.name)
                foundMatches = [foundMatches curFile.name];
            end
        end
    end
end

if ~isempty(foundMatches) || ~isempty(foundMatchesVersioned)
    found = true;
    
    if ~isempty(foundMatches)
        sortedMatches = sort(foundMatches);
        filename = sortedMatches{1};
    else
        sor
    end
else
    found = false;
    filename = '';
end

end
