function [vhistExec] = getVhistExec()
% GETVHISTEXEC    Returns the path to a vhistadd executable usable on this
%                  system.
%    This function searches for a vhistadd executable in the directory of
%    the matvhist bindings and returns the path to this executable.
%    On Windows, .exe Versions of vhistadd will be prefered.
%    If no vhistadd executable can be found, an exception will be thrown.

% get directory of the matvhist package
packageDir = getPackageDir();


% gather all paths where valid vhist executables are located. Paths may be
% prefixed by the "python" command on windows.

paths = {};

p1 = fullfile(packageDir, 'vhist/bin/'); % path in final package
p2 = fullfile(packageDir, '../../core_py/bin/'); % path in repository

if ispc % check for windows
    paths = addExecToPathList(paths, {p1, p2}, 'vhistadd.exe');
    paths = addExecToPathList(paths, {p1, p2}, 'vhistadd.py', 'python ');
else % everything else (mac os x, linux, unix)
    % make-matvhist-release on windows drops exec-permission for vhistadd
    paths = addExecToPathList(paths, {p1, p2}, 'vhistadd.py', 'python ');
end

if isempty(paths)
    throw(MException('could not find a vhist executable'));
end

% use the first executable in the list
vhistExec = paths{1};

end


function [newPaths] = addExecToPathList(oldPaths, additionalPaths, filename, prefix)

newPaths = oldPaths;

for i = 1 : numel(additionalPaths)
    p = additionalPaths{i};
    p = fullfile(p, filename);
    
    if exist(p, 'file')
        if nargin > 3 % prefix was supplied
            p = [prefix p];
        end
        newPaths = [newPaths, p];
    end
end

end


function [packageDir] = getPackageDir()

package = what('+matvhist');

if isempty(package)
    throw(MException('vhist:noPackage', ...
        'Could not find package +matvhist in path.'));
end

packageDir = package.path;

end
