function [newSection, inVhistFile, outVhistFiles] = ...
        handleVhistFiles(section, infilePatterns, outfilePatterns)
% HANDLEVHISTFILES    Tries to automatically detect and embed VHIST files.
%    This function tries to automatically embed VHIST files for all
%    specified input files of the given section. Only input files, which
%    match at least one of the patterns in infilePatterns, are taken into
%    account. Moreover, it returns a list of names for VHIST files, one for
%    each output file which matches at least one pattern in
%    outfilePatterns. These filenames can be used as names for VHIST files,
%    which should be generated by the VhistSection.addVhistSection
%    function. infilePatterns and outfilePatterns are both strings
%    containing a wildcard pattern or a cell array of such
%    strings. section is a matvhist.VhistSection object.
%    
%    One of the input VHIST files will not be embedded, but is returned as
%    a seperate file name. This filename can be used as input VHIST file
%    in a VhistSection.addVhistSection call. handleVhistFile will only
%    consider VHIST files, which do exist in the filesystem and will prefer
%    files, which are both input and output files.
%    
%    See also mathvist.VhistSection.addVhistSection

% get names for output vhist files
outVhistFiles = matvhist.getOutputVhistFiles(section, outfilePatterns);

% embed input VHIST files. outVhistFiles will be used as
% preferedVhistFiles.
[newSection, inVhistFile] = matvhist.addVhistFilesForInputFiles(section, ...
        infilePatterns, outVhistFiles);

% reorder output files, so that inVhistFile is located at the first
% position if it is also in outVhistFiles. Important for vhistadd call.
% Examples:
%    Before: in=foo    out=bar,foo,baz
%    After:  in=foo    out=foo,bar,baz
matchesInfile = @(x) strcmp(x, inVhistFile);
matches = logical(cellfun(matchesInfile, outVhistFiles));
outVhistFiles = [outVhistFiles(matches), outVhistFiles(~matches)];

end
