
% Don't forget to first add the matvhist directory to your matlab path.
% Otherwise, this example won't work.

clear all

%% Step 1: Smooth Image
inputImage = 'input-image.png';
filteredImage = 'filtered-image.png';

smoothImage(inputImage, filteredImage);

f1 = matvhist.VhistFile(inputImage, 'in');
f2 = matvhist.VhistFile(filteredImage, 'out');
f1.embed = false;
f2.embed = false;

section = matvhist.VhistSection('Smooth Image');
section.files = [f1, f2];

section.addVhistSection({[filteredImage '.vhist']}); %, [inputImage '.vhist']);

%% Step 2: Reduce Colors
reducedColorImage = 'reduced-color-image.png';
logFile = 'reduced-colors.log';
params.numIterations = 50;
params.numColors = 100;

reduceColors(filteredImage, reducedColorImage, logFile, params);

f1 = matvhist.VhistFile(filteredImage, 'in');
f2 = matvhist.VhistFile(reducedColorImage, 'out');
f3 = matvhist.VhistFile(logFile, 'out');
f1.embed = false;
f2.embed = false;

section = matvhist.VhistSection('Reduce Number of Colors');
section.files = [f1, f2, f3];
section.userAttrs = matvhist.structToMap(params, 'parameters');

section.addVhistSection({[reducedColorImage '.vhist']}, [filteredImage '.vhist']);

%% Step 3: Calculate Difference of Images
diffImage = 'difference-image.png';
statisticsFile = 'statistics.txt';

calcDifference(filteredImage, reducedColorImage, diffImage, statisticsFile);

f1 = matvhist.VhistFile(filteredImage, 'in');
f1b = matvhist.VhistFile([filteredImage '.vhist'], 'in');
f2 = matvhist.VhistFile(reducedColorImage, 'in');
f3 = matvhist.VhistFile(diffImage, 'out');
f4 = matvhist.VhistFile(statisticsFile, 'out');
f1.embed = false;
f2.embed = false;
f3.embed = false;

section = matvhist.VhistSection('Calculate Difference of Images');
section.files = [f1, f1b, f2, f3, f4];

section.addVhistSection({[diffImage '.vhist'], [statisticsFile '.vhist']}, ...
    [reducedColorImage '.vhist']);

